@@ -79,7 +79,7 @@ draft <- function(file,
     stop("No template.yaml file found for template '", template, "'")
   }
 
-  template_meta <- yaml_load_file_utf8(template_yaml)
+  template_meta <- yaml_load_file(template_yaml)
   if (is.null(template_meta$name) || is.null(template_meta$description)) {
     stop("template.yaml must contain name and description fields")
   }
@@ -92,7 +92,7 @@ draft <- function(file,
   if (create_dir) {
 
     # remove .Rmd extension if necessary
-    file <- tools::file_path_sans_ext(file)
+    file <- xfun::sans_ext(file)
 
     # create dir (new dir only)
     if (dir_exists(file))
@@ -104,7 +104,7 @@ draft <- function(file,
   }
 
   # Ensure we have an Rmd extension
-  if (!identical(tolower(tools::file_ext(file)), "rmd"))
+  if (!identical(tolower(xfun::file_ext(file)), "rmd"))
     file <- paste(file, ".Rmd", sep = "")
 
   # Ensure the file doesn't already exist
