@@ -16,6 +16,15 @@ is_osx <- function() {
   if (is.null(x)) y else x
 }
 
+# a la shiny:::is_available
+is_available <- function(package, version = NULL) {
+  installed <- nzchar(system.file(package = package))
+  if (is.null(version)) {
+    return(installed)
+  }
+  installed && isTRUE(utils::packageVersion(package) >= version)
+}
+
 # determine the output file for a pandoc conversion
 pandoc_output_file <- function(input, pandoc_options) {
   to <- strsplit(pandoc_options$to, "[+-]")[[1]][[1]]
@@ -33,8 +42,17 @@ pandoc_output_ext <- function(ext, to, input) {
   paste0(".", to)
 }
 
-pkg_file <- function(..., package = "rmarkdown") {
-  system.file(..., package = package)
+# needs to handle the case when this function is used in a package loaded with
+# devtools or pkgload load_all(). Required for testing with testthat also.
+# From pkgdown:
+# https://github.com/r-lib/pkgdown/blob/04d3a76892320ac4bd918b39604c157e9f83507a/R/utils-fs.R#L85
+pkg_file <- function(..., package = "rmarkdown", mustWork = FALSE) {
+  if (is.null(devtools_meta(package))) {
+    system.file(..., package = package, mustWork = mustWork)
+  } else {
+    # used only if package has been loaded with devtools or pkgload
+    file.path(getNamespaceInfo(package, "path"), "inst", ...)
+  }
 }
 
 pkg_file_arg <- function(..., package = "rmarkdown") {
@@ -56,10 +74,8 @@ pkg_file_arg <- function(..., package = "rmarkdown") {
 #'   \code{\link{pandoc_path_arg}()}, so they are ready to be used by Pandoc.
 #' @export
 #' @examples
-#' # List all Lua filters stored in the rmarkdown package
+#' # list all Lua filters stored in the rmarkdown package
 #' pkg_file_lua()
-#' # or in a specific package
-#' if (xfun::loadable("bookdown")) pkg_file_lua(package = "bookdown")
 #' # get a specific filter
 #' pkg_file_lua(c("pagebreak.lua", "latex_div.lua"))
 pkg_file_lua <- function(filters = NULL, package = "rmarkdown") {
@@ -148,6 +164,7 @@ clean_tmpfiles <- function() {
   ))
 }
 
+# test if all paths in x are directories
 dir_exists <- function(x) {
   length(x) > 0 && utils::file_test('-d', x)
 }
@@ -295,6 +312,21 @@ find_program <- function(program) {
   }
 }
 
+has_crop_tools <- function() {
+  tools <- c(
+    pdfcrop = unname(find_program("pdfcrop")),
+    ghostcript = unname(tools::find_gs_cmd())
+  )
+  missing <- tools[tools == ""]
+  if (length(missing) == 0) return(TRUE)
+  x <- paste0(names(missing), collapse = ", ")
+  warning(
+    sprintf("\nTool(s) not installed or not in PATH: %s", x),
+    "\n-> As a result, figure cropping will be disabled."
+  )
+  FALSE
+}
+
 # given a string, escape the regex metacharacters it contains:
 # regex metas are these,
 #   . \ | ( ) [ { ^ $ * + ?
@@ -529,3 +561,13 @@ get_loaded_packages <- function() {
     row.names = NULL, stringsAsFactors = FALSE
   )
 }
+
+# devtools metadata -------------------------------------------------------
+
+# from pkgdown
+# https://github.com/r-lib/pkgdown/blob/77f909b0138a1d7191ad9bb3cf95e78d8e8d93b9/R/utils.r#L52
+
+devtools_meta <- function(package) {
+  ns <- .getNamespace(package)
+  ns[[".__DEVTOOLS__"]]
+}
